import java.io.*;
import java.net.Socket;

/** 
 *  UsaProxy - HTTP proxy for tracking and logging of user interactions on websites
    Copyright (C) 2006  Monika Wnuk - Media Informatics Group at the University of Munich
    <br><br>
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    <br><br>
 *  Class ProxyScript is used for the forwarding of proxyscript.js
 */
public class ProxyScript {
	
	/**
     *  Opens a FileInputStream to the file and sends it to the client.
     *  
     *  @param out is the client's OutputStream.
     *  @param file is the file to be send.
     *  @param client is the client's Socket.
     *  @param sessionID is the clients current/new session ID.
     */
	public void send (OutputStream out, String file, Socket client, String sessionID) {
    	
		try { 

			/** Open a stream to the file. Remember that by this
			 *  all the text but the file name has been stripped 
			 *  from the "request" string. */
			FileInputStream fis = new FileInputStream ( file ); 
			
			/** Creat a byte array to hold the file. */
			byte [] data = new byte [ fis.available() ]; 
			
			fis.read( data ); /** Read file into the byte array */
			
			/** header part */
			String cookieText = "";
			if(sessionID!=null) cookieText = sessionID;
			else cookieText = "hallowelthal";
			cookieText = "userUsaProxy=" + cookieText
					+ ";expires=" + HTTPData.COOKIE_EXPIRES_DATE;
					//+ ";domain=.lo.lo";
			
			StringBuffer headers = new StringBuffer();
			
			headers.append("HTTP/1.1 200").append("\r\n");
			if(file.indexOf("proxyscript")>-1) headers.append("Content-Type: text/javascript").append("\r\n");
			headers.append("Set-cookie: " + cookieText).append("\r\n\r\n");
			
			/** data part */
			out = new DataOutputStream(out);
			
			if(file.indexOf("proxyscript")>-1) out.write(headers.toString().getBytes(HTTPData.HEADER_DEFAULT_CHAR_ENCODING));
			
			out.write( data );/** Write it to client output stream */
			out.flush();      /** Remember to flush output buffer */
        }
        catch ( FileNotFoundException e ) { 	
        	/** If no such file, then display the famous 404 message. */
        	/** If log file doesn't exist, display the famous 404 message. */
        	System.err.println("\nAn ERROR occured: script file not found:\n"
									+ e );
        	
        	/** Send 404 error message to client */
			PrintWriter outPrint = new PrintWriter(new OutputStreamWriter(out));
			outPrint.println("HTTP/1.0 404 ");            /** version and status code */
			outPrint.println();                           /** blank line */
			outPrint.flush();
	
        }
        catch ( IOException e ) { 
        	System.err.println("\nAn ERROR occured while sending script file:\n"
							+ e );
        }
    	
    }

}
