import java.net.*; 

/** Interface ProxyType provides methods which are accordingly implemented 
 *  by the different proxy type classes
 */
public interface ProxyType {
	
	/**
     *  Returns a Socket of the server/gateway.
     *  @return the Socket
     */
	public Socket getServerConnect() throws Exception;
	
	/**
     *  Returns the request line.
     *  @param method is the request method
     *  @param url is the requested URL
     *  @return the request String
     */
	public String getRequestLine(String method, URL url);
	
	/**
     *  Returns the script String in the form of a script tag with the proxyscript.js as src attribute.
     *  @return the script String
     */
	public String getScriptString();
	
	/**
	 * Sets the requested URL
	 * @param url is the requestURL to set.
	 */
	public void setRequestURL(URL url);
	
	/**
	 * Returns the host name
	 * @return a host name String
	 */
	public String getHostName();
}
