import java.net.InetAddress;
import java.net.Socket;
import java.net.URL;

/** 
 *  UsaProxy - HTTP proxy for tracking and logging of user interactions on websites
    Copyright (C) 2006  Monika Wnuk - Media Informatics Group at the University of Munich
    <br><br>
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    <br><br>
 *  Class RemoteProxy provides methods which are specifically defined for
 *  remote proxy environments (if UsaProxy is located within a network which
 *  is connected to the Internet by a proxy gateway)
 */

public class RemoteProxy implements ProxyType {
	
	private InetAddress 			remoteProxy;					  /** remote proxy data */
    private int 					remotePort;						  /** remote proxy data */
	
    /** Constructor, creates a RemoteProxy.
     */
	public RemoteProxy() {
		super();
	}
	
	/** Constructor, creates a RemoteProxy with the given remote proxy information.
	 * 
	 * @param remoteProxy is the remote gateway
	 * @param remotePort is the remote gateway port
     */
	public RemoteProxy(InetAddress remoteProxy, int remotePort) {
		super();
		this.remoteProxy 		= remoteProxy;
		this.remotePort 		= remotePort;
	}

	/**
     *  Returns a Socket of the gateway.
     *  
     *  @return the Socket
     */
	public Socket getServerConnect() throws Exception {
		return new Socket(remoteProxy.getHostName(),remotePort);
	}
	
	/**
     *  Returns the request line.
     *  <br><br>
     *  The URL is left unaltered. HTTP version 1.0 is added.
     *  
     *  @param method is the request method
     *  @param url is the requested URL
     *  @return the request String
     */
	public String getRequestLine(String method, URL url) {
		return method + " " + url.toString() + " HTTP/1.0";
	}
	
	/**
     *  Returns the script String in the form of a script tag with the proxyscript.js as src attribute.
     *  The virtual name lo.lo is used as host.
     *  
     *  @return the script String
     */
	public String getScriptString() {
		return "<script src='http://lo.lo/usaproxylolo/proxyscript.js' type='text/javascript'></script>";
	}
	
	/** not implemented by RemoteProxy */
	public void setRequestURL(URL url) {}
	
	/** not implemented by RemoteProxy */
	public String getHostName() { return ""; }

}
